@@ -148,7 +148,7 @@ class Service(object):
       list_on_server = service.get_list("On server")
       in_both = new_list & list_on_server
       in_both.name = "Intersection of these lists"
-      for row in in_both.to_attribute_query().results():
+      for row in in_both:
         do_something_with(row)
         ...
       
